==> openflowplugin-extension-nicira-0.7.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-reg-move-rpc-update-flow-updated-write-actions-case {
 *   uses nx-action-reg-move-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/updated-flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-reg-move-rpc-update-flow-updated-write-actions-case</i>
 *
 */
public interface NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase
    extends
    DataObject,
    Augmentable<NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase>,
    NxActionRegMoveGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-reg-move-rpc-update-flow-updated-write-actions-case");


}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/update/flow/input/updated/flow/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.update.flow.input.updated.flow.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionRegMoveGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-reg-move-rpc-update-flow-updated-write-actions-case {
 *   uses nx-action-reg-move-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/update-flow/input/updated-flow/instructions/instruction/instruction/write-actions-case/write-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-reg-move-rpc-update-flow-updated-write-actions-case</i>
 *
 */
public interface NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase
    extends
    DataObject,
    Augmentable<NxActionRegMoveRpcUpdateFlowUpdatedWriteActionsCase>,
    NxActionRegMoveGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-reg-move-rpc-update-flow-updated-write-actions-case");


}
